package com.platform.yijia.controller;

import com.google.gson.Gson;
import com.platform.yijia.param.request.RechargeBalance;
import com.platform.yijia.pojo.CustomerCardUseRecord;
import com.platform.yijia.pojo.CustomerElectronicCard;
import com.platform.yijia.service.ElectronicMembershipCardService;
import com.platform.yijia.utils.CodeMsg;
import com.platform.yijia.utils.ResultData;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.math.BigDecimal;
import java.util.Date;
import java.util.List;
import java.util.Random;

/*
 * <Title> ElectronicMembershipCardController </Title>
 * <Description> 电子会员卡（储蓄卡）功能模块 </Description>
 * @Author JK
 * @Date 2021年3月22日
 */
@Controller
@RequestMapping("/demo")
public class ElectronicMembershipCardController {
    @Resource
    private ElectronicMembershipCardService electronicMembershipCardService;

    //获取用户储蓄卡列表
    @RequestMapping(value = "/getElectronicCardList", method = RequestMethod.GET)
    @ResponseBody
    public String getElectronicCardList(@RequestParam Integer stationId, String unionId){
        Gson gson =new Gson();
        //返回结果集
        ResultData resultData = null;
        if(stationId !=null && unionId !=null){
            CustomerElectronicCard customerElectronicCard = new CustomerElectronicCard();
            customerElectronicCard.setStationId(stationId);
            customerElectronicCard.setUnionId(unionId);
            List<CustomerElectronicCard> electronicCardList = electronicMembershipCardService.getElectronicCardList(customerElectronicCard);
            resultData = ResultData.success(electronicCardList);
        }else {
            resultData = ResultData.error(CodeMsg.REQUEST_FAIL);
        }
        return gson.toJson(resultData);
    }

    //用户充值储蓄卡
    @RequestMapping(value = "/rechargeBalance", method = RequestMethod.POST)
    @ResponseBody
    public String rechargeBalance(@RequestBody RechargeBalance rechargeBalance){
        Gson gson =new Gson();
        //返回结果集
        ResultData resultData = null;
        if(rechargeBalance !=null){
            BigDecimal amt = new BigDecimal(rechargeBalance.getAmt());
            BigDecimal presentAmt = new BigDecimal(rechargeBalance.getPresentAmt());
            String cardOilsType = rechargeBalance.getCardOilsType();
            String unionId = rechargeBalance.getUnionId();
            String openId = rechargeBalance.getOpenId();    //公众号的openId
            Integer stationId = rechargeBalance.getStationId();
            String stationName = rechargeBalance.getStationName();
            String customerName = rechargeBalance.getCustomerName();
            //String mno = rechargeBalance.getMno();

            //电子会员卡使用记录
            CustomerCardUseRecord customerCardUseRecord = new CustomerCardUseRecord();
            customerCardUseRecord.setUnionId(unionId);
            customerCardUseRecord.setStationId(stationId);
            customerCardUseRecord.setAmt(amt);
            customerCardUseRecord.setPresentAmt(presentAmt);
            customerCardUseRecord.setCardOilsType(cardOilsType);
            customerCardUseRecord.setStationName(stationName);
            customerCardUseRecord.setCustomerName(customerName);
            customerCardUseRecord.setUsageType("+");
            customerCardUseRecord.setType("1");      //1表示微信
            customerCardUseRecord.setCreateTime(new Date());
            //订单规则 时间+6位随机数
            Random random = new Random();
            String str="";
            for(int i=0; i<6; i++){
                str+=random.nextInt(10);
            }
            String orderNo = System.nanoTime()+str;
            customerCardUseRecord.setOrderNo(orderNo);

            //电子会员卡
            CustomerElectronicCard customerElectronicCard = new CustomerElectronicCard();
//            customerElectronicCard.setUnionId(unionId);
//            customerElectronicCard.setStationId(stationId);
//            customerElectronicCard.setCardOilsType(cardOilsType);
            customerElectronicCard.setId(rechargeBalance.getId());
            customerElectronicCard.setRecentlyTime(new Date());

            //获取当前用户要充值的的电子会员卡信息
            CustomerElectronicCard electronicCardInfo = electronicMembershipCardService.getElectronicCardInfo(customerElectronicCard);
            if(electronicCardInfo != null){
                BigDecimal amtBalance = electronicCardInfo.getAmt();        //用户当前卡内余额
                if(presentAmt !=null){  //有赠送金额时
                    customerElectronicCard.setAmt(amtBalance.add(presentAmt).add(amt));
                }else { //无赠送金额时
                    customerElectronicCard.setAmt(amtBalance.add(amt));
                }
                electronicMembershipCardService.updateElectronicCardInfo(customerElectronicCard);   //更新电子会员看余额信息
                electronicMembershipCardService.insetCardUseRecord(customerCardUseRecord);      //插入电子会员卡的使用记录
                resultData = ResultData.success(CodeMsg.SUCCESS);
            }else {
                resultData = ResultData.error(CodeMsg.USER_EXSIST_CARD);
            }
        }else {
            resultData = ResultData.error(CodeMsg.REQUEST_FAIL);
        }
        return gson.toJson(resultData);
    }

    //获取用户储蓄卡充值记录
    @RequestMapping(value = "/getCardRechargeRecord", method = RequestMethod.GET)
    @ResponseBody
    public String getCardRechargeRecord(@RequestParam Integer stationId, String unionId){
        Gson gson =new Gson();
        //返回结果集
        ResultData resultData = null;
        if(stationId !=null && unionId !=null){
            CustomerCardUseRecord customerCardUseRecord = new CustomerCardUseRecord();
            customerCardUseRecord.setUsageType("+"); // '+' 代表充值
            customerCardUseRecord.setStationId(stationId);
            customerCardUseRecord.setUnionId(unionId);
            List<CustomerCardUseRecord> cardUseRecordList = electronicMembershipCardService.getCardUseRecordList(customerCardUseRecord);
            resultData = ResultData.success(cardUseRecordList);
        }else {
            resultData = ResultData.error(CodeMsg.REQUEST_FAIL);
        }
        return gson.toJson(resultData);
    }

    //获取用户储蓄卡消费记录
    @RequestMapping(value = "/getCardConsumptionRecord", method = RequestMethod.GET)
    @ResponseBody
    public String getCardConsumptionRecord(@RequestParam Integer stationId, String unionId){
        Gson gson =new Gson();
        //返回结果集
        ResultData resultData = null;
        if(stationId !=null && unionId !=null){
            CustomerCardUseRecord customerCardUseRecord = new CustomerCardUseRecord();
            customerCardUseRecord.setUnionId(unionId);
            customerCardUseRecord.setStationId(stationId);
            customerCardUseRecord.setUsageType("-"); // '-' 代表消费
            List<CustomerCardUseRecord> cardUseRecordList = electronicMembershipCardService.getCardUseRecordList(customerCardUseRecord);
            resultData = ResultData.success(cardUseRecordList);
        }else {
            resultData = ResultData.error(CodeMsg.REQUEST_FAIL);
        }
        return gson.toJson(resultData);
    }


}
